==> haskell-openssl-streams-1.2.3.0-304-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-K8OWyRlXv8DFU3CH6lBxPC
key:                  openssl-streams-1.2.3.0-K8OWyRlXv8DFU3CH6lBxPC
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  2dcdf42794903f6f7629dbc4032134ac
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-K8OWyRlXv8DFU3CH6lBxPC
depends:
    HsOpenSSL-0.11.7.9-2dJWTXbGJ2o2w7V8hugDcS base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-8umgCc4MkHy4mRoOm8NJN3
    network-3.1.4.0-4q2nDdk2jYz5m5sp4PhmqQ

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.3.0-305-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-4CshDfV7tXyE1OwejM0tNI
key:                  openssl-streams-1.2.3.0-4CshDfV7tXyE1OwejM0tNI
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  b54da4319c2ab838b79ff927a7ccf96b
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-4CshDfV7tXyE1OwejM0tNI
depends:
    HsOpenSSL-0.11.7.9-ABz2mAiFhzZJZi7dc04UNa base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-IdFMpk9YU82L6Lceolbfe6
    network-3.1.4.0-GdpHxCm9XS6F665gL00mHk

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
